@@ -1,9 +1,11 @@
 from django_comments_xtd.api.views import (
     CommentCreate, CommentList, CommentCount,
-    ToggleFeedbackFlag, CreateReportFlag
+    ToggleFeedbackFlag, CreateReportFlag,
+    preview_user_avatar
 )
 
 __all__ = (
     CommentCreate, CommentList, CommentCount,
-    ToggleFeedbackFlag, CreateReportFlag
+    ToggleFeedbackFlag, CreateReportFlag,
+    preview_user_avatar
 )
