@@ -1,8 +1,8 @@
-from django.urls import include, re_path
+from django.urls import include, path, re_path
 
 from rest_framework.urlpatterns import format_suffix_patterns
 
-from django_comments_xtd import api, views
+from django_comments_xtd import views
 
 urlpatterns = [
     re_path(r'^sent/$', views.sent, name='comments-xtd-sent'),
@@ -21,21 +21,10 @@ urlpatterns = [
             name='comments-xtd-dislike-done'),
 
     # API handlers.
-    re_path(r'^api/comment/$', api.CommentCreate.as_view(),
-            name='comments-xtd-api-create'),
-    re_path(r'^api/preview/$', api.preview_user_avatar,
-            name='comments-xtd-api-preview'),
-    re_path(r'^api/(?P<content_type>\w+[-]{1}\w+)/(?P<object_pk>[-\w]+)/$',
-            api.CommentList.as_view(), name='comments-xtd-api-list'),
-    re_path(
-        r'^api/(?P<content_type>\w+[-]{1}\w+)/(?P<object_pk>[-\w]+)/count/$',
-        api.CommentCount.as_view(), name='comments-xtd-api-count'),
-    re_path(r'^api/feedback/$', api.ToggleFeedbackFlag.as_view(),
-            name='comments-xtd-api-feedback'),
-    re_path(r'^api/flag/$', api.CreateReportFlag.as_view(),
-            name='comments-xtd-api-flag'),
+    path('api/', include("django_comments_xtd.api.urls"),
+         {'override_drf_defaults': True}),
 
-    re_path(r'', include("django_comments.urls")),
+    path('', include("django_comments.urls")),
 ]
 
 
